@@ -46,24 +46,27 @@ import yaml
 from .common import ResourceNotFound
 from .environment import get_etc_ros_dir
 
-TARBALL_URI_EVAL ='http://ros-dry-releases.googlecode.com/svn/download/stacks/$STACK_NAME/$STACK_NAME-$STACK_VERSION/$STACK_NAME-$STACK_VERSION.tar.bz2'
+TARBALL_URI_EVAL = 'http://ros-dry-releases.googlecode.com/svn/download/stacks/$STACK_NAME/$STACK_NAME-$STACK_VERSION/$STACK_NAME-$STACK_VERSION.tar.bz2'
 TARBALL_VERSION_EVAL = '$STACK_NAME-$STACK_VERSION'
 
+
 class InvalidDistro(Exception):
     """
     Distro file data does not match specification.
     """
     pass
 
+
 def distro_uri(distro_name):
     """
     Get distro URI of main ROS distribution files.
-    
+
     :param distro_name: name of distro, e.g. 'diamondback'
     :returns: the SVN/HTTP URL of the specified distro.  This function should only be used
       with the main distros.
     """
-    return "http://ros-dry-releases.googlecode.com/svn/trunk/distros/%s.rosdistro"%(distro_name)
+    return "http://ros-dry-releases.googlecode.com/svn/trunk/distros/%s.rosdistro" % (distro_name)
+
 
 def expand_rule(rule, stack_name, stack_ver, release_name):
     s = rule.replace('$STACK_NAME', stack_name)
@@ -72,6 +75,7 @@ def expand_rule(rule, stack_name, stack_ver, release_name):
     s = s.replace('$RELEASE_NAME', release_name)
     return s
 
+
 class DistroStack(object):
     """Stores information about a stack release"""
 
@@ -94,7 +98,7 @@ class DistroStack(object):
         Perform variable substitution on stack rule.
         """
         return expand_rule(rule, self.name, self.version, self.release_name)
-        
+
     def __eq__(self, other):
         try:
             return self.name == other.name and \
@@ -103,6 +107,7 @@ class DistroStack(object):
         except AttributeError:
             return False
 
+
 class Variant(object):
     """
     A variant defines a specific set of stacks ("metapackage", in Debian
@@ -129,13 +134,14 @@ class Variant(object):
 
     # stack_names includes implicit stack names. Use get_stack_names()
     # to get explicit only
-    stack_names  = property(get_stack_names)
-    
+    stack_names = property(get_stack_names)
+
+
 class Distro(object):
     """
     Store information in a rosdistro file.
     """
-    
+
     def __init__(self, stacks, variants, release_name, version, raw_data):
         """
         :param stacks: dictionary mapping stack names to :class:`DistroStack` instances
@@ -163,7 +169,7 @@ class Distro(object):
 
     def _get_released_stacks(self):
         retval = {}
-        for s, obj in self._stacks.items(): #py3k
+        for s, obj in self._stacks.items():
             if obj.version:
                 retval[s] = obj
         return retval
@@ -173,6 +179,7 @@ class Distro(object):
     # gets maps of released stacks
     released_stacks = property(_get_released_stacks)
 
+
 def load_distro(source_uri):
     """
     :param source_uri: source URI of distro file, or path to distro
@@ -197,7 +204,7 @@ def load_distro(source_uri):
             except ValueError:
                 raise ResourceNotFound(source_uri)
         if not type(raw_data) == dict:
-            raise InvalidDistro("Distro must be a dictionary: %s"%(source_uri))
+            raise InvalidDistro("Distro must be a dictionary: %s" % (source_uri))
     except yaml.YAMLError as e:
         raise InvalidDistro(str(e))
 
@@ -208,7 +215,8 @@ def load_distro(source_uri):
         variants = _load_variants(raw_data.get('variants', {}), stacks)
         return Distro(stacks, variants, release_name, version, raw_data)
     except KeyError as e:
-        raise InvalidDistro("distro is missing required '%s' key"%(str(e)))
+        raise InvalidDistro("distro is missing required '%s' key" % (str(e)))
+
 
 def _load_variants(raw_data, stacks):
     if not raw_data:
@@ -216,31 +224,33 @@ def _load_variants(raw_data, stacks):
     all_variants_raw_data = {}
     for v in raw_data:
         if type(v) != dict or len(v.keys()) != 1:
-            raise InvalidDistro("invalid variant spec: %s"%v)
+            raise InvalidDistro("invalid variant spec: %s" % v)
         variant_name = list(v.keys())[0]
         all_variants_raw_data[variant_name] = v[variant_name]
     variants = {}
     for variant_name in all_variants_raw_data.keys():
         variants[variant_name] = _load_variant(variant_name, all_variants_raw_data)
-        
-        # Disabling validation to support variants which include wet packages.  
+
+        # Disabling validation to support variants which include wet packages.
         # validate
-        #for stack_name in variants[variant_name].get_stack_names(implicit=False):
-        #    if stack_name not in stacks:
-        #        raise InvalidDistro("variant [%s] refers to non-existent stack [%s]"%(variant_name, stack_name))
+        # for stack_name in variants[variant_name].get_stack_names(implicit=False):
+        #     if stack_name not in stacks:
+        #         raise InvalidDistro("variant [%s] refers to non-existent stack [%s]"%(variant_name, stack_name))
     return variants
-        
+
+
 def _load_variant(variant_name, all_variants_raw_data):
     variant_raw_data = all_variants_raw_data[variant_name]
     stack_names_implicit = list(variant_raw_data.get('stacks', []))
     extends = variant_raw_data.get('extends', [])
-    if type(extends) == type('str'):
+    if isinstance(extends, str):
         extends = [extends]
     for e in extends:
         parent_variant = _load_variant(e, all_variants_raw_data)
         stack_names_implicit = parent_variant.get_stack_names(implicit=True) + stack_names_implicit
     return Variant(variant_name, extends, variant_raw_data.get('stacks', []), stack_names_implicit)
-    
+
+
 def _load_distro_stacks(distro_doc, release_name):
     """
     :param distro_doc: dictionary form of rosdistro file, `dict`
@@ -260,10 +270,11 @@ def _load_distro_stacks(distro_doc, release_name):
         stack_version = stack_props[stack_name].get('version', None)
         rules = _get_rules(distro_doc, stack_name)
         if not rules:
-            raise InvalidDistro("no VCS rules for stack [%s]"%(stack_name))
+            raise InvalidDistro("no VCS rules for stack [%s]" % (stack_name))
         stacks[stack_name] = DistroStack(stack_name, stack_version, release_name, rules)
     return stacks
 
+
 def _distro_version(version_val):
     """
     Parse distro version value, converting SVN revision to version value if necessary
@@ -274,14 +285,15 @@ def _distro_version(version_val):
         return 0
     m = re.search('\$Revision:\s*([0-9]*)\s*\$', version_val)
     if m is not None:
-        version_val = 'r'+m.group(1)
+        version_val = 'r' + m.group(1)
 
     # Check that is a valid version string
     valid = string.ascii_letters + string.digits + '.+~'
     if False in (c in valid for c in version_val):
-        raise InvalidDistro("Version string %s not valid"%version_val)
+        raise InvalidDistro("Version string %s not valid" % version_val)
     return version_val
 
+
 def distro_to_rosinstall(distro, branch, variant_name=None, implicit=True, released_only=True, anonymous=True):
     """
     :param branch: branch to convert for
@@ -300,13 +312,14 @@ def distro_to_rosinstall(distro, branch, variant_name=None, implicit=True, relea
         stack_names = distro.released_stacks.keys()
     rosinstall_data = []
     for s in stack_names:
-        if released_only and not s in distro.released_stacks:
+        if released_only and s not in distro.released_stacks:
             continue
         rosinstall_data.extend(distro.stacks[s].vcs_config.to_rosinstall(s, branch, anonymous))
     return rosinstall_data
 
 ################################################################################
 
+
 def _get_rules(distro_doc, stack_name):
     """
     Retrieve rules from distro_doc for specified stack.  This operates on
@@ -326,19 +339,21 @@ def _get_rules(distro_doc, stack_name):
     # last rules wins
     if not rules_d:
         return None
-    rules_d = rules_d[-1] 
+    rules_d = rules_d[-1]
 
     update_r = rules_d.get('_rules', {})
     if type(update_r) == str:
         try:
             update_r = named_rules_d[update_r]
         except KeyError:
-            raise InvalidDistro("no _rules named [%s]"%(update_r))
+            raise InvalidDistro("no _rules named [%s]" % (update_r))
     if not type(update_r) == dict:
-        raise InvalidDistro("invalid rules: %s %s"%(update_r, type(update_r)))
+        raise InvalidDistro("invalid rules: %s %s" % (update_r, type(update_r)))
     return update_r
-        
+
 ################################################################################
+
+
 class VcsConfig(object):
     """
     Base representation of a rosdistro VCS rules configuration.
@@ -347,7 +362,7 @@ class VcsConfig(object):
     def __init__(self, type_):
         self.type = type_
         self.tarball_url = self.tarball_version = None
-        
+
     def to_rosinstall(self, local_name, branch, anonymous):
         uri, version_tag = self.get_branch(branch, anonymous)
         if branch == 'release-tar':
@@ -355,10 +370,10 @@ class VcsConfig(object):
         else:
             type_ = self.type
         if version_tag:
-            return [{type_: {"uri": uri, 'local-name': local_name, 'version': version_tag} } ]
+            return [{type_: {"uri": uri, 'local-name': local_name, 'version': version_tag}}]
         else:
-            return [({type_: {"uri": uri, 'local-name': local_name} } )]
-        
+            return [({type_: {"uri": uri, 'local-name': local_name}})]
+
     def load(self, rules, rule_eval):
         """
         Initialize fields of this class based on the raw rosdistro
@@ -370,7 +385,7 @@ class VcsConfig(object):
         """
         self.tarball_url = rule_eval(TARBALL_URI_EVAL)
         self.tarball_version = rule_eval(TARBALL_VERSION_EVAL)
-        
+
     def get_branch(self, branch, anonymous):
         """
         :raises: :exc:`ValueError` If branch is invalid
@@ -382,14 +397,15 @@ class VcsConfig(object):
 
     def __eq__(self, other):
         return self.type == other.type and \
-               self.tarball_url == other.tarball_url
+            self.tarball_url == other.tarball_url
+
 
 class DvcsConfig(VcsConfig):
     """
     Configuration information for a distributed VCS-style repository.
 
     Configuration fields:
-    
+
      * ``repo_uri``: base URI of repo
      * ``dev_branch``: git branch the code is developed
      * ``distro_tag``: a tag of the latest released code for a specific ROS distribution
@@ -399,7 +415,7 @@ class DvcsConfig(VcsConfig):
     def __init__(self, type_):
         super(DvcsConfig, self).__init__(type_)
         self.repo_uri = self.anon_repo_uri = None
-        self.dev_branch = self.distro_tag = self.release_tag   = None
+        self.dev_branch = self.distro_tag = self.release_tag = None
 
     def load(self, rules, rule_eval):
         super(DvcsConfig, self).load(rules, rule_eval)
@@ -409,16 +425,16 @@ class DvcsConfig(VcsConfig):
             self.anon_repo_uri = rule_eval(rules['anon-uri'])
         else:
             self.anon_repo_uri = self.repo_uri
-        self.dev_branch  = rule_eval(rules['dev-branch'])
-        self.distro_tag  = rule_eval(rules['distro-tag'])
+        self.dev_branch = rule_eval(rules['dev-branch'])
+        self.distro_tag = rule_eval(rules['distro-tag'])
         self.release_tag = rule_eval(rules['release-tag'])
-        
+
     def get_branch(self, branch, anonymous):
         """
-        :raises: :exc:`KeyError` Invalid branch parameter 
+        :raises: :exc:`KeyError` Invalid branch parameter
         """
         if branch == 'release-tar':
-            return super(DvcsConfig, self).get_branch(branch, anonymous)            
+            return super(DvcsConfig, self).get_branch(branch, anonymous)
         elif branch == 'devel':
             version_tag = self.dev_branch
         elif branch == 'distro':
@@ -426,23 +442,24 @@ class DvcsConfig(VcsConfig):
         elif branch == 'release':
             version_tag = self.release_tag
         else:
-            raise ValueError("invalid branch spec [%s]"%(branch))
+            raise ValueError("invalid branch spec [%s]" % (branch))
         # occurs, for example, with unreleased stacks.  Only devel is valid
         if version_tag is None:
-            raise ValueError("branch [%s] is not available for this config"%(branch))
+            raise ValueError("branch [%s] is not available for this config" % (branch))
         if anonymous:
             return self.anon_repo_uri, version_tag
         else:
-            return self.repo_uri, version_tag            
-        
+            return self.repo_uri, version_tag
+
     def __eq__(self, other):
         return super(DvcsConfig, self).__eq__(other) and \
-               self.repo_uri == other.repo_uri and \
-               self.anon_repo_uri == other.anon_repo_uri and \
-               self.dev_branch == other.dev_branch and \
-               self.release_tag == other.release_tag and \
-               self.distro_tag == other.distro_tag
-    
+            self.repo_uri == other.repo_uri and \
+            self.anon_repo_uri == other.anon_repo_uri and \
+            self.dev_branch == other.dev_branch and \
+            self.release_tag == other.release_tag and \
+            self.distro_tag == other.distro_tag
+
+
 class GitConfig(DvcsConfig):
     """
     Configuration information about an GIT repository. See parent class :class:`DvcsConfig` for more API information.
@@ -451,6 +468,7 @@ class GitConfig(DvcsConfig):
     def __init__(self):
         super(GitConfig, self).__init__('git')
 
+
 class HgConfig(DvcsConfig):
     """
     Configuration information about a Mercurial repository. See parent class :class:`DvcsConfig` for more API information.
@@ -459,6 +477,7 @@ class HgConfig(DvcsConfig):
     def __init__(self):
         super(HgConfig, self).__init__('hg')
 
+
 class BzrConfig(DvcsConfig):
     """
     Configuration information about an BZR repository.  See parent class :class:`DvcsConfig` for more API information.
@@ -467,17 +486,18 @@ class BzrConfig(DvcsConfig):
     def __init__(self):
         super(BzrConfig, self).__init__('bzr')
 
+
 class SvnConfig(VcsConfig):
     """
     Configuration information about an SVN repository.
 
     Configuration fields:
-    
+
      * ``dev``: where the code is developed
      * ``distro_tag``: a tag of the code for a specific ROS distribution
      * ``release_tag``: a tag of the code for a specific release
     """
-    
+
     def __init__(self):
         super(SvnConfig, self).__init__('svn')
         self.dev = None
@@ -488,24 +508,24 @@ class SvnConfig(VcsConfig):
         # separate URLs for read-only vs. writable versions of repo
         # and many tools need to be able to read repos without
         # providing credentials.
-        self.anon_dev         = None
-        self.anon_distro_tag  = None
+        self.anon_dev = None
+        self.anon_distro_tag = None
         self.anon_release_tag = None
-        
+
     def load(self, rules, rule_eval):
         super(SvnConfig, self).load(rules, rule_eval)
         for k in ['dev', 'distro-tag', 'release-tag']:
-            if not k in rules:
-                raise KeyError("svn rules missing required %s key: %s"%(k, rules))
+            if k not in rules:
+                raise KeyError("svn rules missing required %s key: %s" % (k, rules))
         self.dev = rule_eval(rules['dev'])
-        self.distro_tag  = rule_eval(rules['distro-tag'])
+        self.distro_tag = rule_eval(rules['distro-tag'])
         self.release_tag = rule_eval(rules['release-tag'])
 
         # specify urls that are safe to anonymously read
         # from. Users must supply a complete set.
         if 'anon-dev' in rules:
             self.anon_dev = rule_eval(rules['anon-dev'])
-            self.anon_distro_tag = rule_eval(rules['anon-distro-tag'])                
+            self.anon_distro_tag = rule_eval(rules['anon-distro-tag'])
             self.anon_release_tag = rule_eval(rules['anon-release-tag'])
         else:
             # if no login credentials, assume that anonymous is
@@ -513,8 +533,8 @@ class SvnConfig(VcsConfig):
             self.anon_dev = self.dev
             self.anon_distro_tag = self.distro_tag
             self.anon_release_tag = self.release_tag
-        
-    def get_branch(self, branch, anonymous):        
+
+    def get_branch(self, branch, anonymous):
         """
         :raises: :exc:`ValueError` If branch is invalid
         """
@@ -522,32 +542,34 @@ class SvnConfig(VcsConfig):
             return super(SvnConfig, self).get_branch(branch, anonymous)
         else:
             key_map = dict(devel='dev', distro='distro_tag', release='release_tag')
-            if not branch in key_map:
-                raise KeyError("invalid branch spec [%s]"%(branch))
+            if branch not in key_map:
+                raise KeyError("invalid branch spec [%s]" % (branch))
             attr_name = key_map[branch]
             if anonymous:
-                attr_name = 'anon_'+attr_name
+                attr_name = 'anon_' + attr_name
             uri = getattr(self, attr_name)
         # occurs, for example, with unreleased stacks.  Only devel is valid
         if uri is None:
-            raise ValueError("branch [%s] is not available for this config"%(branch))
+            raise ValueError("branch [%s] is not available for this config" % (branch))
         return uri, None
-        
+
     def __eq__(self, other):
         return super(SvnConfig, self).__eq__(other) and \
-               self.dev == other.dev and \
-               self.distro_tag == other.distro_tag and \
-               self.release_tag == other.release_tag and \
-               self.anon_dev == other.anon_dev and \
-               self.anon_distro_tag == other.anon_distro_tag and \
-               self.anon_release_tag == other.anon_release_tag
+            self.dev == other.dev and \
+            self.distro_tag == other.distro_tag and \
+            self.release_tag == other.release_tag and \
+            self.anon_dev == other.anon_dev and \
+            self.anon_distro_tag == other.anon_distro_tag and \
+            self.anon_release_tag == other.anon_release_tag
+
 
 _vcs_configs = {
     'svn': SvnConfig,
     'git': GitConfig,
-    'hg': HgConfig,    
-    'bzr': BzrConfig,    
-    }
+    'hg': HgConfig,
+    'bzr': BzrConfig,
+}
+
 
 def get_vcs_configs():
     """
@@ -556,6 +578,7 @@ def get_vcs_configs():
     """
     return _vcs_configs.copy()
 
+
 def load_vcs_config(rules, rule_eval):
     """
     Factory for creating :class:`VcsConfig` subclass based on
@@ -574,6 +597,7 @@ def load_vcs_config(rules, rule_eval):
             break
     return vcs_config
 
+
 def _current_distro_electric_parse_roscore(roscore_file):
     if not os.path.exists(roscore_file):
         return None
@@ -586,7 +610,8 @@ def _current_distro_electric_parse_roscore(roscore_file):
                 return t.getAttribute('value')
     except:
         return None
-    
+
+
 # for < fuerte, retrieve from roscore file
 def _current_distro_electric(env=None):
     if env is None:
@@ -600,6 +625,7 @@ def _current_distro_electric(env=None):
     except:
         return None
 
+
 def current_distro_codename(env=None):
     """
     Get the currently active ROS distribution codename, e.g. 'fuerte'
@@ -608,7 +634,7 @@ def current_distro_codename(env=None):
     """
     if env is None:
         env = os.environ
-        
+
     # ROS_DISTRO is only used in ros catkin buildspace.  It is not
     # meant to be well publicized and thus is not declared in
     # rospkg.environment.
@@ -628,4 +654,3 @@ def current_distro_codename(env=None):
         distro_name = _current_distro_electric(env=env)
 
     return distro_name
-
