@@ -30,9 +30,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-import os
-import sys
-
 default_rules = {}
 rosinstalls = {}
 default_rules['git'] = {'git': {'anon-uri': 'https://github.com/ipa320/$STACK_NAME.git',
@@ -42,7 +39,7 @@ default_rules['git'] = {'git': {'anon-uri': 'https://github.com/ipa320/$STACK_NA
                                 'uri': 'git@github.com:ipa320/$STACK_NAME.git'}}
 rosinstalls['git'] = {}
 rosinstalls['git']['release-tar'] = [{'tar': {'local-name': 'local_name',
-                                              'version': '$STACK_NAME-$STACK_VERSIONevaled', 
+                                              'version': '$STACK_NAME-$STACK_VERSIONevaled',
                                               'uri': 'http://ros-dry-releases.googlecode.com/svn/download/stacks/$STACK_NAME/$STACK_NAME-$STACK_VERSION/$STACK_NAME-$STACK_VERSION.tar.bz2evaled'}}]
 rosinstalls['git']['devel'] = [{'git': {'local-name': 'local_name',
                                         'version': 'release_electricevaled',
@@ -65,8 +62,8 @@ rosinstalls['svn']['release'] = [{'svn': {'local-name': 'local_name',
                                           'uri': 'https://alufr-ros-pkg.googlecode.com/svn/tags/stacks/$STACK_NAME/$STACK_NAME-$STACK_VERSIONevaled',
                                           }}]
 rosinstalls['svn']['distro'] = [{'svn': {'local-name': 'local_name',
-                                          'uri': 'https://alufr-ros-pkg.googlecode.com/svn/tags/distros/$RELEASE_NAME/stacks/$STACK_NAMEevaled',
-                                          }}]
+                                         'uri': 'https://alufr-ros-pkg.googlecode.com/svn/tags/distros/$RELEASE_NAME/stacks/$STACK_NAMEevaled',
+                                         }}]
 default_rules['hg'] = {'hg': {'dev-branch': 'default',
                               'distro-tag': '$RELEASE_NAME',
                               'release-tag': '$STACK_NAME-$STACK_VERSION',
@@ -77,17 +74,21 @@ default_rules['bzr'] = {'bzr': {'anon-uri': 'lp:sr-ros-interface',
                                 'release-tag': '$STACK_NAME-$STACK_VERSION',
                                 'uri': 'bzr+ssh://bazaar.launchpad.net/~shadowrobot/sr-ros-interface'}}
 
+
 def test_to_rosinstall():
     from rospkg.distro import load_vcs_config
-    rule_eval = lambda x: x+'evaled'
+
+    def rule_eval(x):
+        return x + 'evaled'
     anonymous = True
-    #TODO: for branch in ['devel', 'release', 'distro']:
+    # TODO: for branch in ['devel', 'release', 'distro']:
     for vcs in ['git', 'svn']:
         vcs_config = load_vcs_config(default_rules[vcs], rule_eval)
         for branch in ['release', 'distro', 'release-tar', 'devel']:
             retval = vcs_config.to_rosinstall('local_name', branch, anonymous)
-            assert retval == rosinstalls[vcs][branch], "%s %s:\n%s\nvs.\n%s"%(vcs, branch, retval, rosinstalls[vcs][branch])
-    
+            assert retval == rosinstalls[vcs][branch], "%s %s:\n%s\nvs.\n%s" % (vcs, branch, retval, rosinstalls[vcs][branch])
+
+
 def test_VcsConfig():
     from rospkg.distro import VcsConfig
     vcs_config = VcsConfig('fake')
@@ -96,11 +97,13 @@ def test_VcsConfig():
     for b in ['devel', 'release', 'distro']:
         try:
             vcs_config.get_branch(b, False)
-            assert False, "should have raised"+b
-        except ValueError: pass
+            assert False, "should have raised" + b
+        except ValueError:
+            pass
     for anon in [True, False]:
         assert ('http://foo', None) == vcs_config.get_branch('release-tar', anon)
-    
+
+
 def test_BZRConfig():
     from rospkg.distro import BzrConfig
     anon_rules = default_rules['bzr']['bzr']
@@ -118,13 +121,14 @@ def test_BZRConfig():
         try:
             config.load(bad_copy, lambda x: x)
             assert False, "should have raised"
-        except KeyError: pass
-    
-    config.load(rules, lambda x: x+'evaled')
-    anon_config.load(anon_rules, lambda x: x+'evaled')
+        except KeyError:
+            pass
 
-    repo_uri = anon_rules['uri']+'evaled'
-    anon_repo_uri = anon_rules['anon-uri']+'evaled'
+    config.load(rules, lambda x: x + 'evaled')
+    anon_config.load(anon_rules, lambda x: x + 'evaled')
+
+    repo_uri = anon_rules['uri'] + 'evaled'
+    anon_repo_uri = anon_rules['anon-uri'] + 'evaled'
     assert config.repo_uri == anon_repo_uri, config.repo_uri
     assert config.anon_repo_uri == anon_repo_uri, config.anon_repo_uri
     assert anon_config.repo_uri == repo_uri, anon_config.repo_uri
@@ -155,25 +159,26 @@ def test_BZRConfig():
     except ValueError:
         pass
     c.release_tag = rel_tag
-    
+
     # test equals
     config2 = BzrConfig()
-    config2.load(rules, lambda x: x+'evaled')
+    config2.load(rules, lambda x: x + 'evaled')
     assert config == config2
-    anon_config2 = BzrConfig()    
-    anon_config2.load(anon_rules, lambda x: x+'evaled')
+    anon_config2 = BzrConfig()
+    anon_config2.load(anon_rules, lambda x: x + 'evaled')
     assert anon_config == anon_config2
 
     # test eq
     config_check = BzrConfig()
     config_check_eq = BzrConfig()
     config_check_neq = BzrConfig()
-    config_check.load(rules, lambda x: x+'evaled')
-    config_check_eq.load(rules, lambda x: x+'evaled')
-    config_check_neq.load(anon_rules, lambda x: x+'evaled')
+    config_check.load(rules, lambda x: x + 'evaled')
+    config_check_eq.load(rules, lambda x: x + 'evaled')
+    config_check_neq.load(anon_rules, lambda x: x + 'evaled')
     assert config_check == config_check_eq
     assert config_check != config_check_neq
 
+
 def test_HgConfig():
     from rospkg.distro import HgConfig
     anon_rules = {
@@ -182,8 +187,8 @@ def test_HgConfig():
         'release-tag': '$STACK_NAME-$STACK_VERSION',
         'anon-uri': 'https://kforge.ros.org/navigation/navigation',
         'uri': 'ssh://user@kforge.ros.org/navigation/navigation'
-        }
-    rules = default_rules['hg']['hg'] 
+    }
+    rules = default_rules['hg']['hg']
 
     config = HgConfig()
     anon_config = HgConfig()
@@ -195,10 +200,11 @@ def test_HgConfig():
         try:
             config.load(bad_copy, lambda x: x)
             assert False, "should have raised"
-        except KeyError: pass
-    
-    config.load(rules, lambda x: x+'evaled')
-    anon_config.load(anon_rules, lambda x: x+'evaled')
+        except KeyError:
+            pass
+
+    config.load(rules, lambda x: x + 'evaled')
+    anon_config.load(anon_rules, lambda x: x + 'evaled')
 
     repo_uri = 'ssh://user@kforge.ros.org/navigation/navigationevaled'
     anon_repo_uri = 'https://kforge.ros.org/navigation/navigationevaled'
@@ -221,22 +227,23 @@ def test_HgConfig():
 
     # test equals
     config2 = HgConfig()
-    config2.load(rules, lambda x: x+'evaled')
+    config2.load(rules, lambda x: x + 'evaled')
     assert config == config2
-    anon_config2 = HgConfig()    
-    anon_config2.load(anon_rules, lambda x: x+'evaled')
+    anon_config2 = HgConfig()
+    anon_config2.load(anon_rules, lambda x: x + 'evaled')
     assert anon_config == anon_config2
 
     # test eq
     config_check = HgConfig()
     config_check_eq = HgConfig()
     config_check_neq = HgConfig()
-    config_check.load(rules, lambda x: x+'evaled')
-    config_check_eq.load(rules, lambda x: x+'evaled')
-    config_check_neq.load(anon_rules, lambda x: x+'evaled')
+    config_check.load(rules, lambda x: x + 'evaled')
+    config_check_eq.load(rules, lambda x: x + 'evaled')
+    config_check_neq.load(anon_rules, lambda x: x + 'evaled')
     assert config_check == config_check_eq
     assert config_check != config_check_neq
 
+
 def test_GitConfig():
     from rospkg.distro import GitConfig
     anon_rules = default_rules['git']['git']
@@ -253,13 +260,14 @@ def test_GitConfig():
         try:
             config.load(bad_copy, lambda x: x)
             assert False, "should have raised"
-        except KeyError: pass
-    
-    config.load(rules, lambda x: x+'evaled')
-    anon_config.load(anon_rules, lambda x: x+'evaled')
+        except KeyError:
+            pass
+
+    config.load(rules, lambda x: x + 'evaled')
+    anon_config.load(anon_rules, lambda x: x + 'evaled')
     repo_uri = 'git@github.com:ipa320/$STACK_NAME.gitevaled'
-    anon_repo_uri ='https://github.com/ipa320/$STACK_NAME.gitevaled'
-    
+    anon_repo_uri = 'https://github.com/ipa320/$STACK_NAME.gitevaled'
+
     assert config.repo_uri == repo_uri
     assert anon_config.anon_repo_uri == anon_repo_uri
     for c in [config, anon_config]:
@@ -279,12 +287,13 @@ def test_GitConfig():
 
     # test equals
     config2 = GitConfig()
-    config2.load(rules, lambda x: x+'evaled')
+    config2.load(rules, lambda x: x + 'evaled')
     assert config == config2
-    anon_config2 = GitConfig()    
-    anon_config2.load(anon_rules, lambda x: x+'evaled')
+    anon_config2 = GitConfig()
+    anon_config2.load(anon_rules, lambda x: x + 'evaled')
     assert anon_config == anon_config2
 
+
 def test_SvnConfig():
     from rospkg.distro import SvnConfig
     config = SvnConfig()
@@ -306,10 +315,11 @@ def test_SvnConfig():
         try:
             config.load(bad_copy, lambda x: x)
             assert False, "should have raised"
-        except KeyError: pass
-        
+        except KeyError:
+            pass
+
     # load w/o anon rules
-    config.load(rules, lambda x: x+'evaled')
+    config.load(rules, lambda x: x + 'evaled')
     assert config.dev == 'https://alufr-ros-pkg.googlecode.com/svn/trunk/$STACK_NAMEevaled'
     assert config.distro_tag == 'https://alufr-ros-pkg.googlecode.com/svn/tags/distros/$RELEASE_NAME/stacks/$STACK_NAMEevaled'
     assert config.release_tag == 'https://alufr-ros-pkg.googlecode.com/svn/tags/stacks/$STACK_NAME/$STACK_NAME-$STACK_VERSIONevaled'
@@ -322,16 +332,16 @@ def test_SvnConfig():
     config_check = SvnConfig()
     config_check_eq = SvnConfig()
     config_check_neq = SvnConfig()
-    config_check.load(rules, lambda x: x+'evaled')
-    config_check_eq.load(rules, lambda x: x+'evaled')
-    config_check_neq.load(anon_rules, lambda x: x+'evaled')
+    config_check.load(rules, lambda x: x + 'evaled')
+    config_check_eq.load(rules, lambda x: x + 'evaled')
+    config_check_neq.load(anon_rules, lambda x: x + 'evaled')
     assert config_check == config_check_eq
     assert config_check != config_check_neq
-    
+
     # load w anon rules
     config2 = SvnConfig()
-    config.load(anon_rules, lambda x: x+'evaled')
-    config2.load(anon_rules, lambda x: x+'evaled')
+    config.load(anon_rules, lambda x: x + 'evaled')
+    config2.load(anon_rules, lambda x: x + 'evaled')
     for c in [config, config2]:
         assert c.anon_dev == 'http://svn.mech.kuleuven.be/repos/orocos/trunk/kul-ros-pkg/stacks/$STACK_NAME/trunkevaled'
         assert c.anon_distro_tag == 'http://svn.mech.kuleuven.be/repos/orocos/trunk/kul-ros-pkg/stacks/$STACK_NAME/tags/$RELEASE_NAMEevaled'
@@ -364,9 +374,10 @@ def test_SvnConfig():
         pass
     c.release_tag = rel_tag
 
+
 def test_load_vcs_config():
     from rospkg.distro import load_vcs_config, get_vcs_configs
     for t in ['svn', 'git', 'hg', 'bzr']:
         assert t in get_vcs_configs()
-        config = load_vcs_config(default_rules[t], lambda x: x+'evaled')
+        config = load_vcs_config(default_rules[t], lambda x: x + 'evaled')
         assert config.type == t, t
